<!DOCTYPE html>
<html lang="zh-cn">
<head>
    <meta charset="utf-8">
    <title></title>
    <link href="file:\\{{template_path}}/main.css" rel="stylesheet" type="text/css">
    <link href="file:\\{{template_path}}/avatar.css" rel="stylesheet" type="text/css">
</head>
<style>

    {%if data['userInfo']['avatar']['poster']['status']==2 %}
        .main-content{
            background: url("{{data['userInfo']['avatar']['poster']['data']}}") no-repeat;
            background-position: center;
            background-size: cover;
            min-height: 100vh
        }
    {% endif %}

    {%if data['userInfo']['avatar']['colorName']['status']==2 %}
        .mirage-text {
            background: {{ data['userInfo']['avatar']['colorName']['data'] }};
            background-size: 200% 200%;
            color: transparent;
            -webkit-background-clip: text;
            animation: ran-7e872de5 3s linear infinite;
        }
    {% endif %}

    .page-header {
    {%if data['userInfo']['avatar']['banner']['status']==2 %}
        background: url("{{data['userInfo']['avatar']['banner']['data']}}") no-repeat;
    {% endif %}
        background-position: center;
        background-size: 100%;
    }

    .avatar-header {
    {%if data['userInfo']['avatar']['avatar']['status']==2 %}
        background: url("{{data['userInfo']['avatar']['avatar']['data']}}") no-repeat;
    {% else %}
        background: url("{{data['userInfo']['dogTag']}}") no-repeat;
    {% endif %}
        background-position: center;
        background-size: 100%;
    }
</style>
<body>
<div class="main-content">
    <div class="page-box">
        <div class="page-header">
            <div class="masking-header">
                <div class="avatar-header"></div>
                <div class="clan-user-server">
                    <div class="user-info ">
                        {#                    是否有工会#}
                        {% if data['userInfo']['clanInfo']['tag'] %}
                            <span style="color: {{ data['userInfo']['clanInfo']['color'] }};">[{{ data['userInfo']['clanInfo']['tag'] }}]</span>
                        {% endif %}
                        <span class="mirage-text">{{ data['userInfo']['userName'] }}</span></div>
                    <div class="user-sign-time">注册时间: <span
                            class="server-style">{{ time.strftime('%Y-%m-%d %H:%M',time.localtime(int(abs(data['userInfo']['accountCreateTime'])))) }}</span>
                    </div>
                    <div class="user-server">服务器: <span class="server server-style">{{ data['userInfo']['serverCn'] }}</span></div>
                    {% if data['userInfo']['avatar']['sign']['status'] == 2 %}
                        <div class="user-signature">
                            {{ data['userInfo']['avatar']['sign']['data'] }}
                        </div>
                    {% endif %}
                </div>
            </div>
        </div>

        <div class="ship-header">
             <span
                     style="
                             background: url('{{ data['recentInfo'][0]['shipInfoBattleList'][0]['shipInfo']['countryImage'] }}')
                             no-repeat;
                             background-size: contain;
                             background-position: center;
                             margin-left: 10px;
                             padding: 40px;
                             margin-right: 10px;
                             "
             ></span>
            <span
                    style="
                            background: url('{{ data['recentInfo'][0]['shipInfoBattleList'][0]['shipInfo']['shipTypeImage'] }}')
                            no-repeat;
                            background-size: contain;
                            background-position: center;
                            padding: 40px;
                            margin-right: 10px;
                            "
            ></span>
            <span style="margin-right: 20px">{{ data['recentInfo'][0]['shipInfoBattleList'][0]['shipInfo']['levelStr'] }}</span>
            <img class="ship-box"
                 src="{{ data['recentInfo'][0]['shipInfoBattleList'][0]['shipInfo']['imgSmall'] }}"
                 style="background-size: contain;background-position: 50% 30%;width: 120px;height: 100%;">

            {{ data['recentInfo'][0]['shipInfoBattleList'][0]['shipInfo']['nameCn'] }}
        </div>

        <div class="pr">
            <div class="svg-waves">
                <svg viewBox="0 0 500 200" preserveAspectRatio="none">
                    <path class="wave-path" d="M0,100 C150,200 350,0 500,100 L500,200 L0,200 Z"></path>
                </svg>
            </div>
            {% if data['battleTypeInfoList']['PVP']['battle'] %}
                <span class="pr-number">{{ data['battleTypeInfoList']['PVP']['prInfo']['value'] }}&nbsp;&nbsp;&nbsp;&nbsp;<span
                        class="pr-text">{{ data['battleTypeInfoList']['PVP']['prInfo']['name'] }}</span></span>
            {% else %}
                <span class="pr-number">{{ data['battleTypeInfoList']['RANK_SOLO']['prInfo']['value'] }}&nbsp;&nbsp;&nbsp;&nbsp;<span
                        class="pr-text">{{ data['battleTypeInfoList']['RANK_SOLO']['prInfo']['name'] }}</span></span>
            {% endif %}
        </div>

        <div class="recnet-time">
            <span>记录时间：</span><span>{{ time.strftime('%Y-%m-%d %H:%M',time.localtime(int(abs(data['recentInfo'][0]['recordTime']/1000)))) }}—{{ time.strftime('%Y-%m-%d %H:%M',time.localtime(time.time())) }}</span>
        </div>

        {% if data['battleTypeInfoList']['PVP']['battle'] %}
            <div class="overview-change">
                <div class="overview-change-item left-item">
                    <div class="left-item-top item-top one-background-color">
                        <div class="overview-count-title item-top-top">场次</div>
                        <div class="overview-count item-top-bottom">{{ data['battleTypeInfoList']['PVP']['battleInfo']['battleInfo']['battle'] }}</div>
                    </div>
                    <div class="left-item-bottom item-bottom">
                        <div class="change-avgdmg-box bottom-mini-item-left one-background-color">
                            <div class="mini-item-top">加成经验</div>
                            <div class="mini-item-bottom">{{ data['battleTypeInfoList']['PVP']['battleInfo']['avgInfo']['xp'] }}</div>
                        </div>
                        <div class="change-win-box bottom-mini-item-right one-background-color">
                            <div class="mini-item-top">命中率</div>
                            <div class="mini-item-bottom">{{ data['battleTypeInfoList']['PVP']['battleInfo']['hitRatioInfo']['ratioMain'] }}%</div>
                        </div>
                    </div>
                </div>
                <div class="overview-change-item mid-item">
                    <div class="mid-item-top item-top one-background-color">
                        <div class="overview-win-title item-top-top">胜率</div>
                        <div class="overview-win item-top-bottom"
                             style="color: {{ data['battleTypeInfoList']['PVP']['battleInfo']['avgInfo']['winsData']['color'] }};">{{ data['battleTypeInfoList']['PVP']['battleInfo']['avgInfo']['win'] }}%
                        </div>
                    </div>
                    <div class="mid-item-bottom item-bottom">
                        <div class="change-avgdmg-box bottom-mini-item-left one-background-color">
                            <div class="mini-item-top">侦察</div>
                            <div class="mini-item-bottom">{{ '%.2f' | format(data['battleTypeInfoList']['PVP']['battleInfo']['avgInfo']['shipsSpotted']) }}</div>
                        </div>
                        <div class="change-win-box bottom-mini-item-right one-background-color">
                            <div class="mini-item-top">击落</div>
                            <div class="mini-item-bottom">{{ '%.2f' | format(data['battleTypeInfoList']['PVP']['battleInfo']['avgInfo']['planesKilled']) }}</div>
                        </div>
                    </div>
                </div>
                <div class="overview-change-item right-item">
                    <div class="right-item-top item-top one-background-color">
                        <div class="overview-avgdmg-title item-top-top">场均</div>
                        <div class="overview-avgdmg item-top-bottom"
                             style="color: {{ data['battleTypeInfoList']['PVP']['battleInfo']['avgInfo']['damageData']['color'] }};">{{ data['battleTypeInfoList']['PVP']['battleInfo']['avgInfo']['damage'] }}</div>
                    </div>
                    <div class="right-item-bottom item-bottom">
                        <div class="overview-kd-box bottom-mini-item-left one-background-color">
                            <div class="mini-item-top">击杀</div>
                            <div class="mini-item-bottom">{{ '%.2f' | format(data['battleTypeInfoList']['PVP']['battleInfo']['avgInfo']['frags']) }}</div>
                        </div>
                        <div class="overview-hit-box bottom-mini-item-right one-background-color">
                            <div class="mini-item-top">KD</div>
                            <div class="mini-item-bottom">{{ '%.2f' | format(data['battleTypeInfoList']['PVP']['battleInfo']['avgInfo']['kd']) }}</div>
                        </div>
                    </div>
                </div>
            </div>
        {% else %}
            <!--否则显示排位-->
            <div class="overview-change">
                <div class="overview-change-item left-item">
                    <div class="left-item-top item-top one-background-color">
                        <div class="overview-count-title item-top-top">场次</div>
                        <div class="overview-count item-top-bottom">{{ data['battleTypeInfoList']['RANK_SOLO']['battleInfo']['battleInfo']['battle'] }}</div>
                    </div>
                    <div class="left-item-bottom item-bottom">
                        <div class="change-avgdmg-box bottom-mini-item-left one-background-color">
                            <div class="mini-item-top">加成经验</div>
                            <div class="mini-item-bottom">{{ data['battleTypeInfoList']['RANK_SOLO']['battleInfo']['avgInfo']['xp'] }}</div>
                        </div>
                        <div class="change-win-box bottom-mini-item-right one-background-color">
                            <div class="mini-item-top">命中率</div>
                            <div class="mini-item-bottom">{{ data['battleTypeInfoList']['RANK_SOLO']['battleInfo']['hitRatioInfo']['ratioMain'] }}%</div>
                        </div>
                    </div>
                </div>
                <div class="overview-change-item mid-item">
                    <div class="mid-item-top item-top one-background-color">
                        <div class="overview-win-title item-top-top">胜率</div>
                        <div class="overview-win item-top-bottom"
                             style="color: {{ data['battleTypeInfoList']['RANK_SOLO']['battleInfo']['avgInfo']['winsData']['color'] }};">{{ data['battleTypeInfoList']['RANK_SOLO']['battleInfo']['avgInfo']['win'] }}%
                        </div>
                    </div>
                    <div class="mid-item-bottom item-bottom">
                        <div class="change-avgdmg-box bottom-mini-item-left one-background-color">
                            <div class="mini-item-top">侦察</div>
                            <div class="mini-item-bottom">{{ '%.2f' | format(data['battleTypeInfoList']['RANK_SOLO']['battleInfo']['avgInfo']['shipsSpotted']) }}</div>
                        </div>
                        <div class="change-win-box bottom-mini-item-right one-background-color">
                            <div class="mini-item-top">击落</div>
                            <div class="mini-item-bottom">{{ '%.2f' | format(data['battleTypeInfoList']['RANK_SOLO']['battleInfo']['avgInfo']['planesKilled']) }}</div>
                        </div>
                    </div>
                </div>
                <div class="overview-change-item right-item">
                    <div class="right-item-top item-top one-background-color">
                        <div class="overview-avgdmg-title item-top-top">场均</div>
                        <div class="overview-avgdmg item-top-bottom"
                             style="color: {{ data['battleTypeInfoList']['RANK_SOLO']['battleInfo']['avgInfo']['damageData']['color'] }};">{{ data['battleTypeInfoList']['RANK_SOLO']['battleInfo']['avgInfo']['damage'] }}</div>
                    </div>
                    <div class="right-item-bottom item-bottom">
                        <div class="overview-kd-box bottom-mini-item-left one-background-color">
                            <div class="mini-item-top">击杀</div>
                            <div class="mini-item-bottom">{{ '%.2f' | format(data['battleTypeInfoList']['RANK_SOLO']['battleInfo']['avgInfo']['frags']) }}</div>
                        </div>
                        <div class="overview-hit-box bottom-mini-item-right one-background-color">
                            <div class="mini-item-top">KD</div>
                            <div class="mini-item-bottom">{{ '%.2f' | format(data['battleTypeInfoList']['RANK_SOLO']['battleInfo']['avgInfo']['kd']) }}</div>
                        </div>
                    </div>
                </div>
            </div>
        {% endif %}

        <div class="random-header one-background-color">战斗类型</div>
        <div class="information-body one-background-color data-battle-type">
            <div class="information-col ">
                <div class="information-col-item">类型</div>
                <div class="information-col-item">场次</div>
                <div class="information-col-item">胜率</div>
                <div class="information-col-item">PR</div>
                <div class="information-col-item">场均</div>
                <div class="information-col-item">击杀</div>
                <div class="information-col-item">命中</div>
            </div>
            {% if data['battleTypeInfoList']['PVP_SOLO']['battle'] %}
                <div class="information-col">
                    <div class="information-col-item">单野</div>
                    <div class="information-col-item">{{ data['battleTypeInfoList']['PVP_SOLO']['battleInfo']['battleInfo']['battle'] }}</div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfoList']['PVP_SOLO']['battleInfo']['avgInfo']['winsData']['color'] }};">{{ data['battleTypeInfoList']['PVP_SOLO']['battleInfo']['avgInfo']['win'] }}%
                    </div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfoList']['PVP_SOLO']['prInfo']['color'] }};">{{ data['battleTypeInfoList']['PVP_SOLO']['prInfo']['value'] }}</div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfoList']['PVP_SOLO']['battleInfo']['avgInfo']['damageData']['color'] }};">{{ data['battleTypeInfoList']['PVP_SOLO']['battleInfo']['avgInfo']['damage'] }}</div>
                    <div class="information-col-item">{{ '%.2f' | format(data['battleTypeInfoList']['PVP_SOLO']['battleInfo']['avgInfo']['frags']) }}</div>
                    <div class="information-col-item">{{ '%.2f' | format(data['battleTypeInfoList']['PVP_SOLO']['battleInfo']['hitRatioInfo']['ratioMain']) }}%</div>
                </div>
            {% endif %}

            {% if data['battleTypeInfoList']['PVP_DIV2']['battle'] %}
                <div class="information-col">
                    <div class="information-col-item">自行车</div>
                    <div class="information-col-item">{{ data['battleTypeInfoList']['PVP_DIV2']['battleInfo']['battleInfo']['battle'] }}</div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfoList']['PVP_DIV2']['battleInfo']['avgInfo']['winsData']['color'] }};">{{ data['battleTypeInfoList']['PVP_DIV2']['battleInfo']['avgInfo']['win'] }}%
                    </div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfoList']['PVP_DIV2']['prInfo']['color'] }};">{{ data['battleTypeInfoList']['PVP_DIV2']['prInfo']['value'] }}</div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfoList']['PVP_DIV2']['battleInfo']['avgInfo']['damageData']['color'] }};">{{ data['battleTypeInfoList']['PVP_DIV2']['battleInfo']['avgInfo']['damage'] }}</div>
                    <div class="information-col-item">{{ '%.2f' | format(data['battleTypeInfoList']['PVP_DIV2']['battleInfo']['avgInfo']['frags']) }}</div>
                    <div class="information-col-item">{{ '%.2f' | format(data['battleTypeInfoList']['PVP_DIV2']['battleInfo']['hitRatioInfo']['ratioMain']) }}%</div>
                </div>
            {% endif %}

            {% if data['battleTypeInfoList']['PVP_DIV3']['battle'] %}
                <div class="information-col">
                    <div class="information-col-item">三轮车</div>
                    <div class="information-col-item">{{ data['battleTypeInfoList']['PVP_DIV3']['battleInfo']['battleInfo']['battle'] }}</div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfoList']['PVP_DIV3']['battleInfo']['avgInfo']['winsData']['color'] }};">{{ data['battleTypeInfoList']['PVP_DIV3']['battleInfo']['avgInfo']['win'] }}%
                    </div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfoList']['PVP_DIV3']['prInfo']['color'] }};">{{ data['battleTypeInfoList']['PVP_DIV3']['prInfo']['value'] }}</div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfoList']['PVP_DIV3']['battleInfo']['avgInfo']['damageData']['color'] }};">{{ data['battleTypeInfoList']['PVP_DIV3']['battleInfo']['avgInfo']['damage'] }}</div>
                    <div class="information-col-item">{{ '%.2f' | format(data['battleTypeInfoList']['PVP_DIV3']['battleInfo']['avgInfo']['frags']) }}</div>
                    <div class="information-col-item">{{ '%.2f' | format(data['battleTypeInfoList']['PVP_DIV3']['battleInfo']['hitRatioInfo']['ratioMain']) }}%</div>
                </div>
            {% endif %}

            {% if data['battleTypeInfoList']['RANK_SOLO']['battle'] %}
                <div class="information-col">
                    <div class="information-col-item">排位</div>
                    <div class="information-col-item">{{ data['battleTypeInfoList']['RANK_SOLO']['battleInfo']['battleInfo']['battle'] }}</div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfoList']['RANK_SOLO']['battleInfo']['avgInfo']['winsData']['color'] }};">{{ data['battleTypeInfoList']['RANK_SOLO']['battleInfo']['avgInfo']['win'] }}%
                    </div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfoList']['RANK_SOLO']['prInfo']['color'] }};">{{ data['battleTypeInfoList']['RANK_SOLO']['prInfo']['value'] }}</div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfoList']['RANK_SOLO']['battleInfo']['avgInfo']['damageData']['color'] }};">{{ data['battleTypeInfoList']['RANK_SOLO']['battleInfo']['avgInfo']['damage'] }}</div>
                    <div class="information-col-item">{{ '%.2f' | format(data['battleTypeInfoList']['RANK_SOLO']['battleInfo']['avgInfo']['frags']) }}</div>
                    <div class="information-col-item">{{ '%.2f' | format(data['battleTypeInfoList']['RANK_SOLO']['battleInfo']['hitRatioInfo']['ratioMain']) }}%</div>
                </div>
            {% endif %}
        </div>



        <div class="random-header one-background-color">每日战绩</div>
        <div class="information-body one-background-color data-battle-type">
            <div class="information-col ">
                <div class="information-col-item">类型</div>
                <div class="information-col-item">场次</div>
                <div class="information-col-item">胜率</div>
                <div class="information-col-item">PR</div>
                <div class="information-col-item">场均</div>
                <div class="information-col-item">击杀</div>
                <div class="information-col-item">命中</div>
            </div>
            {% for eachShipData in data['recentInfo'] %}
                <div class="information-col">{{ time.strftime('%Y-%m-%d',time.localtime(int(abs(eachShipData['recordTime']/1000)))) }}</div>
            {% if eachShipData['battleTypeInfoList']['PVP_SOLO']['battle'] %}
                <div class="information-col">
                    <div class="information-col-item">单野</div>
                    <div class="information-col-item">{{ eachShipData['shipInfoBattleList'][0]['typeInfo']['PVP_SOLO']['battleInfo']['battleInfo']['battle'] }}</div>
                    <div class="information-col-item"
                         style="color: {{ eachShipData['shipInfoBattleList'][0]['typeInfo']['PVP_SOLO']['battleInfo']['avgInfo']['winsData']['color'] }};">{{ eachShipData['battleTypeInfoList']['PVP_SOLO']['battleInfo']['avgInfo']['win'] }}%
                    </div>
                    <div class="information-col-item"
                         style="color: {{ eachShipData['shipInfoBattleList'][0]['typeInfo']['PVP_SOLO']['prInfo']['color'] }};">{{ eachShipData['battleTypeInfoList']['PVP_SOLO']['prInfo']['value'] }}</div>
                    <div class="information-col-item"
                         style="color: {{ eachShipData['shipInfoBattleList'][0]['typeInfo']['PVP_SOLO']['battleInfo']['avgInfo']['damageData']['color'] }};">{{ eachShipData['battleTypeInfoList']['PVP_SOLO']['battleInfo']['avgInfo']['damage'] }}</div>
                    <div class="information-col-item">{{ '%.2f' | format(eachShipData['shipInfoBattleList'][0]['typeInfo']['PVP_SOLO']['battleInfo']['avgInfo']['frags']) }}</div>
                    <div class="information-col-item">{{ '%.2f' | format(eachShipData['shipInfoBattleList'][0]['typeInfo']['PVP_SOLO']['battleInfo']['hitRatioInfo']['ratioMain']) }}%</div>
                </div>
            {% endif %}
                {% if eachShipData['battleTypeInfoList']['PVP_DIV2']['battle'] %}
                    <div class="information-col">
                        <div class="information-col-item">自行车</div>
                        <div class="information-col-item">{{ eachShipData['shipInfoBattleList'][0]['typeInfo']['PVP_DIV2']['battleInfo']['battleInfo']['battle'] }}</div>
                        <div class="information-col-item"
                             style="color: {{ eachShipData['shipInfoBattleList'][0]['typeInfo']['PVP_DIV2']['battleInfo']['avgInfo']['winsData']['color'] }};">{{ eachShipData['battleTypeInfoList']['PVP_DIV2']['battleInfo']['avgInfo']['win'] }}%
                        </div>
                        <div class="information-col-item"
                             style="color: {{ eachShipData['shipInfoBattleList'][0]['typeInfo']['PVP_DIV2']['prInfo']['color'] }};">{{ eachShipData['battleTypeInfoList']['PVP_DIV2']['prInfo']['value'] }}</div>
                        <div class="information-col-item"
                             style="color: {{ eachShipData['shipInfoBattleList'][0]['typeInfo']['PVP_DIV2']['battleInfo']['avgInfo']['damageData']['color'] }};">{{ eachShipData['battleTypeInfoList']['PVP_DIV2']['battleInfo']['avgInfo']['damage'] }}</div>
                        <div class="information-col-item">{{ '%.2f' | format(eachShipData['shipInfoBattleList'][0]['typeInfo']['PVP_DIV2']['battleInfo']['avgInfo']['frags']) }}</div>
                        <div class="information-col-item">{{ '%.2f' | format(eachShipData['shipInfoBattleList'][0]['typeInfo']['PVP_DIV2']['battleInfo']['hitRatioInfo']['ratioMain']) }}%</div>
                    </div>
                {% endif %}
                {% if eachShipData['battleTypeInfoList']['PVP_DIV3']['battle'] %}
                    <div class="information-col">
                        <div class="information-col-item">自行车</div>
                        <div class="information-col-item">{{ eachShipData['shipInfoBattleList'][0]['typeInfo']['PVP_DIV3']['battleInfo']['battleInfo']['battle'] }}</div>
                        <div class="information-col-item"
                             style="color: {{ eachShipData['shipInfoBattleList'][0]['typeInfo']['PVP_DIV3']['battleInfo']['avgInfo']['winsData']['color'] }};">{{ eachShipData['battleTypeInfoList']['PVP_DIV3']['battleInfo']['avgInfo']['win'] }}%
                        </div>
                        <div class="information-col-item"
                             style="color: {{ eachShipData['shipInfoBattleList'][0]['typeInfo']['PVP_DIV3']['prInfo']['color'] }};">{{ eachShipData['battleTypeInfoList']['PVP_DIV3']['prInfo']['value'] }}</div>
                        <div class="information-col-item"
                             style="color: {{ eachShipData['shipInfoBattleList'][0]['typeInfo']['PVP_DIV3']['battleInfo']['avgInfo']['damageData']['color'] }};">{{ eachShipData['battleTypeInfoList']['PVP_DIV3']['battleInfo']['avgInfo']['damage'] }}</div>
                        <div class="information-col-item">{{ '%.2f' | format(eachShipData['shipInfoBattleList'][0]['typeInfo']['PVP_DIV3']['battleInfo']['avgInfo']['frags']) }}</div>
                        <div class="information-col-item">{{ '%.2f' | format(eachShipData['shipInfoBattleList'][0]['typeInfo']['PVP_DIV3']['battleInfo']['hitRatioInfo']['ratioMain']) }}%</div>
                    </div>
                {% endif %}
                {% if eachShipData['battleTypeInfoList']['RANK_SOLO']['battle'] %}
                    <div class="information-col">
                        <div class="information-col-item">自行车</div>
                        <div class="information-col-item">{{ eachShipData['shipInfoBattleList'][0]['typeInfo']['RANK_SOLO']['battleInfo']['battleInfo']['battle'] }}</div>
                        <div class="information-col-item"
                             style="color: {{ eachShipData['shipInfoBattleList'][0]['typeInfo']['RANK_SOLO']['battleInfo']['avgInfo']['winsData']['color'] }};">{{ eachShipData['battleTypeInfoList']['RANK_SOLO']['battleInfo']['avgInfo']['win'] }}%
                        </div>
                        <div class="information-col-item"
                             style="color: {{ eachShipData['shipInfoBattleList'][0]['typeInfo']['RANK_SOLO']['prInfo']['color'] }};">{{ eachShipData['battleTypeInfoList']['RANK_SOLO']['prInfo']['value'] }}</div>
                        <div class="information-col-item"
                             style="color: {{ eachShipData['shipInfoBattleList'][0]['typeInfo']['RANK_SOLO']['battleInfo']['avgInfo']['damageData']['color'] }};">{{ eachShipData['battleTypeInfoList']['RANK_SOLO']['battleInfo']['avgInfo']['damage'] }}</div>
                        <div class="information-col-item">{{ '%.2f' | format(eachShipData['shipInfoBattleList'][0]['typeInfo']['RANK_SOLO']['battleInfo']['avgInfo']['frags']) }}</div>
                        <div class="information-col-item">{{ '%.2f' | format(eachShipData['shipInfoBattleList'][0]['typeInfo']['RANK_SOLO']['battleInfo']['hitRatioInfo']['ratioMain']) }}%</div>
                    </div>
                {% endif %}
            {% endfor %}
        </div>

        <div class="footer">
            <p>频道搜索"战舰世界-yuyuko"即可使用稳定的腾讯官方机器人~</p>
            <p>©github:wows-yuyuko</p>
        </div>
</div>
</body>
<script src="file:\\{{template_path}}/main.js" type="text/javascript"></script>
</html>
