<!DOCTYPE html>
<html lang="zh-cn">
<head>
    <meta charset="utf-8">
    <title></title>
    <link href="file:\\{{template_path}}/main.css" rel="stylesheet" type="text/css">
    <link href="file:\\{{template_path}}/avatar.css" rel="stylesheet" type="text/css">
</head>
<style>

    {%if data['userInfo']['avatar']['poster']['status']==2 %}
        .main-content{
            background: url("{{data['userInfo']['avatar']['poster']['data']}}") no-repeat;
            background-position: center;
            background-size: cover;
            min-height: 100vh
        }
    {% endif %}

    {%if data['userInfo']['avatar']['colorName']['status']==2 %}
        .mirage-text {
            background: {{ data['userInfo']['avatar']['colorName']['data'] }};
            background-size: 200% 200%;
            color: transparent;
            -webkit-background-clip: text;
            animation: ran-7e872de5 3s linear infinite;
        }
    {% endif %}

    .page-header {
    {%if data['userInfo']['avatar']['banner']['status']==2 %}
        background: url("{{data['userInfo']['avatar']['banner']['data']}}") no-repeat;
    {% endif %}
        background-position: center;
        background-size: 100%;
    }

    .avatar-header {
    {%if data['userInfo']['avatar']['avatar']['status']==2 %}
        background: url("{{data['userInfo']['avatar']['avatar']['data']}}") no-repeat;
    {% else %}
        background: url("{{data['userInfo']['dogTag']}}") no-repeat;
    {% endif %}
        background-position: center;
        background-size: 100%;
    }
</style>
<body>
<div class="main-content">
    <div class="page-box">
        <div class="page-header">
            <div class="masking-header">
                <div class="avatar-header"></div>
                <div class="clan-user-server">
                    <div class="user-info ">
                        {#                    是否有工会#}
                        {% if data['userInfo']['clanInfo']['tag'] %}
                            <span style="color: {{ data['userInfo']['clanInfo']['color'] }};">[{{ data['userInfo']['clanInfo']['tag'] }}]</span>
                        {% endif %}
                        <span class="mirage-text">{{ data['userInfo']['userName'] }}</span></div>
                    <div class="user-sign-time">注册时间: <span
                            class="server-style">{{ time.strftime('%Y-%m-%d %H:%M',time.localtime(int(abs(data['userInfo']['accountCreateTime'])))) }}</span>
                    </div>
                    <div class="user-server">服务器: <span class="server server-style">{{ data['userInfo']['serverCn'] }}</span></div>
                    {% if data['userInfo']['avatar']['sign']['status'] == 2 %}
                        <div class="user-signature">
                            {{ data['userInfo']['avatar']['sign']['data'] }}
                        </div>
                    {% endif %}
                </div>
            </div>
        </div>

        <div class="pr">
            <div class="svg-waves">
                <svg viewBox="0 0 500 200" preserveAspectRatio="none">
                    <path class="wave-path" d="M0,100 C150,200 350,0 500,100 L500,200 L0,200 Z"></path>
                </svg>
            </div>
            {% if data['battleTypeInfo']['PVP']['battle'] %}
                <span class="pr-number">{{ data['battleTypeInfo']['PVP']['prInfo']['value'] }}
                    &nbsp;&nbsp;&nbsp;&nbsp;<span
                            class="pr-text">{{ data['battleTypeInfo']['PVP']['prInfo']['name'] }}</span></span>
            {% else %}
                <span class="pr-number">{{ data['battleTypeInfo']['RANK_SOLO']['prInfo']['value'] }}
                    &nbsp;&nbsp;&nbsp;&nbsp;<span
                            class="pr-text">{{ data['battleTypeInfo']['RANK_SOLO']['prInfo']['name'] }}</span></span>
            {% endif %}
        </div>

        <div class="recnet-time">
            <span>最后战斗时间：</span><span>{{ time.strftime('%Y-%m-%d %H:%M:%S',time.localtime(abs(data['lastBattleTime'])))}}</span>
        </div>

        <div class="information-body one-background-color">
            <div class="information-col">
                <div class="information-col-item">场均</div>
                <div class="information-col-item">胜率</div>
                <div class="information-col-item">PR</div>
            </div>
            <div class="information-col">
                <div class="information-col-item change-avgdmg">{{ data['dwpData']['damage'] }}</div>
                <div class="information-col-item change-win">{{ data['dwpData']['wins'] }}</div>
                <div class="information-col-item change-pr">{{ data['dwpData']['pr'] }}</div>
            </div>
        </div>

        {% if data['battleTypeInfo']['PVP']['battle'] %}
            <div class="overview-change">
                <div class="overview-change-item left-item">
                    <div class="left-item-top item-top one-background-color">
                        <div class="overview-count-title item-top-top">场次</div>
                        <div class="overview-count item-top-bottom">{{ data['battleTypeInfo']['PVP']['shipInfo']['battleInfo']['battle'] }}</div>
                    </div>
                    <div class="left-item-bottom item-bottom">
                        <div class="change-avgdmg-box bottom-mini-item-left one-background-color">
                            <div class="mini-item-top">加成经验</div>
                            <div class="mini-item-bottom ">{{ data['battleTypeInfo']['PVP']['shipInfo']['avgInfo']['xp'] }}</div>
                        </div>
                        <div class="change-win-box bottom-mini-item-right one-background-color">
                            <div class="mini-item-top">命中率</div>
                            <div class="mini-item-bottom">{{ data['battleTypeInfo']['PVP']['shipInfo']['hitRatioInfo']['ratioMain'] }}%</div>
                        </div>
                    </div>
                </div>
                <div class="overview-change-item mid-item">
                    <div class="mid-item-top item-top one-background-color">
                        <div class="overview-win-title item-top-top">胜率</div>
                        <div class="overview-win item-top-bottom"
                             style="color: {{ data['battleTypeInfo']['PVP']['shipInfo']['avgInfo']['winsData']['color'] }};">{{ data['battleTypeInfo']['PVP']['shipInfo']['avgInfo']['win'] }}%
                        </div>
                    </div>
                    <div class="mid-item-bottom item-bottom">
                        <div class="change-avgdmg-box bottom-mini-item-left one-background-color">
                            <div class="mini-item-top">侦察</div>
                            <div class="mini-item-bottom">{{ '%.2f' | format(data['battleTypeInfo']['PVP']['shipInfo']['avgInfo']['shipsSpotted']) }}</div>
                        </div>
                        <div class="change-win-box bottom-mini-item-right one-background-color">
                            <div class="mini-item-top">击落</div>
                            <div class="mini-item-bottom">{{ '%.2f' | format(data['battleTypeInfo']['PVP']['shipInfo']['avgInfo']['planesKilled']) }}</div>
                        </div>
                    </div>
                </div>
                <div class="overview-change-item right-item">
                    <div class="right-item-top item-top one-background-color">
                        <div class="overview-avgdmg-title item-top-top">场均</div>
                        <div class="overview-avgdmg item-top-bottom"
                             style="color: {{ data['battleTypeInfo']['PVP']['shipInfo']['avgInfo']['damageData']['color'] }};">{{ data['battleTypeInfo']['PVP']['shipInfo']['avgInfo']['damage'] }}
                        </div>
                    </div>
                    <div class="right-item-bottom item-bottom">
                        <div class="overview-kd-box bottom-mini-item-left one-background-color">
                            <div class="mini-item-top">击杀</div>
                            <div class="mini-item-bottom">{{ '%.2f' | format(data['battleTypeInfo']['PVP']['shipInfo']['avgInfo']['frags']) }}</div>
                        </div>
                        <div class="overview-hit-box bottom-mini-item-right one-background-color">
                            <div class="mini-item-top">KD</div>
                            <div class="mini-item-bottom">{{ '%.2f' | format(data['battleTypeInfo']['PVP']['shipInfo']['avgInfo']['kd']) }}</div>
                        </div>
                    </div>
                </div>
            </div>
        {% else %}
            <!--否则显示排位-->
            <div class="overview-change">
                <div class="overview-change-item left-item">
                    <div class="left-item-top item-top one-background-color">
                        <div class="overview-count-title item-top-top">场次</div>
                        <div class="overview-count item-top-bottom">{{ data['battleTypeInfo']['RANK_SOLO']['shipInfo']['battleInfo']['battle'] }}</div>
                    </div>
                    <div class="left-item-bottom item-bottom">
                        <div class="change-avgdmg-box bottom-mini-item-left one-background-color">
                            <div class="mini-item-top">加成经验</div>
                            <div class="mini-item-bottom">{{ data['battleTypeInfo']['RANK_SOLO']['shipInfo']['avgInfo']['xp'] }}</div>
                        </div>
                        <div class="change-win-box bottom-mini-item-right one-background-color">
                            <div class="mini-item-top">命中率</div>
                            <div class="mini-item-bottom ">{{ data['battleTypeInfo']['RANK_SOLO']['shipInfo']['hitRatioInfo']['ratioMain'] }}%</div>
                        </div>
                    </div>
                </div>
                <div class="overview-change-item mid-item">
                    <div class="mid-item-top item-top one-background-color">
                        <div class="overview-win-title item-top-top">胜率</div>
                        <div class="overview-win item-top-bottom"
                             style="color: {{ data['battleTypeInfo']['RANK_SOLO']['shipInfo']['avgInfo']['winsData']['color'] }};">{{ data['battleTypeInfo']['RANK_SOLO']['shipInfo']['avgInfo']['win'] }}%
                        </div>
                    </div>
                    <div class="mid-item-bottom item-bottom">
                        <div class="change-avgdmg-box bottom-mini-item-left one-background-color">
                            <div class="mini-item-top">侦察</div>
                            <div class="mini-item-bottom">{{ '%.2f' | format(data['battleTypeInfo']['RANK_SOLO']['shipInfo']['avgInfo']['shipsSpotted']) }}</div>
                        </div>
                        <div class="change-win-box bottom-mini-item-right one-background-color">
                            <div class="mini-item-top">击落</div>
                            <div class="mini-item-bottom">{{ '%.2f' | format(data['battleTypeInfo']['RANK_SOLO']['shipInfo']['avgInfo']['planesKilled']) }}</div>
                        </div>
                    </div>
                </div>
                <div class="overview-change-item right-item">
                    <div class="right-item-top item-top one-background-color">
                        <div class="overview-avgdmg-title item-top-top">场均</div>
                        <div class="overview-avgdmg item-top-bottom"
                             style="color: {{ data['battleTypeInfo']['RANK_SOLO']['shipInfo']['avgInfo']['damageData']['color'] }};">{{ data['battleTypeInfo']['RANK_SOLO']['shipInfo']['avgInfo']['damage'] }}</div>
                    </div>
                    <div class="right-item-bottom item-bottom">
                        <div class="overview-kd-box bottom-mini-item-left one-background-color">
                            <div class="mini-item-top">击杀</div>
                            <div class="mini-item-bottom">{{ '%.2f' | format(data['battleTypeInfo']['RANK_SOLO']['shipInfo']['avgInfo']['frags']) }}</div>
                        </div>
                        <div class="overview-hit-box bottom-mini-item-right one-background-color">
                            <div class="mini-item-top">KD</div>
                            <div class="mini-item-bottom">{{ '%.2f' | format(data['battleTypeInfo']['RANK_SOLO']['shipInfo']['avgInfo']['kd']) }}</div>
                        </div>
                    </div>
                </div>
            </div>
        {% endif %}

        <div class="random-header one-background-color">战舰类型</div>

        <div class="information-body one-background-color data-battle-type">
            <div class="information-col">
                <div class="information-col-item">类型</div>
                <div class="information-col-item">场次</div>
                <div class="information-col-item">胜率</div>
                <div class="information-col-item">PR</div>
                <div class="information-col-item">场均</div>
                <div class="information-col-item">击杀</div>
                <div class="information-col-item">命中</div>
            </div>
            {% if data['shipTypeInfo']['Battleship']['PVP']['battle'] %}
                <div class="information-col">
                    <div class="information-col-item">战列舰</div>
                    <div class="information-col-item">{{ data['shipTypeInfo']['Battleship']['PVP']['shipInfo']['battleInfo']['battle'] }}</div>
                    <div class="information-col-item" style="color: {{ data['shipTypeInfo']['Battleship']['PVP']['shipInfo']['avgInfo']['winsData']['color'] }};">{{ data['shipTypeInfo']['Battleship']['PVP']['shipInfo']['avgInfo']['win'] }}%</div>
                    <div class="information-col-item" style="color: {{ data['shipTypeInfo']['Battleship']['PVP']['prInfo']['color'] }};">{{ data['shipTypeInfo']['Battleship']['PVP']['prInfo']['value'] }}</div>
                    <div class="information-col-item" style="color: {{ data['shipTypeInfo']['Battleship']['PVP']['shipInfo']['avgInfo']['damageData']['color'] }};">{{ data['shipTypeInfo']['Battleship']['PVP']['shipInfo']['avgInfo']['damage'] }}</div>
                    <div class="information-col-item">{{ data['shipTypeInfo']['Battleship']['PVP']['shipInfo']['avgInfo']['frags'] }}</div>
                    <div class="information-col-item">{{ data['shipTypeInfo']['Battleship']['PVP']['shipInfo']['hitRatioInfo']['ratioMain'] }}%</div>
                </div>
            {% endif %}
            {% if data['shipTypeInfo']['Cruiser']['PVP']['battle'] %}
                <div class="information-col">
                    <div class="information-col-item">巡洋舰</div>
                    <div class="information-col-item">{{ data['shipTypeInfo']['Cruiser']['PVP']['shipInfo']['battleInfo']['battle'] }}</div>
                    <div class="information-col-item" style="color: {{ data['shipTypeInfo']['Cruiser']['PVP']['shipInfo']['avgInfo']['winsData']['color'] }};">{{ data['shipTypeInfo']['Cruiser']['PVP']['shipInfo']['avgInfo']['win'] }}%</div>
                    <div class="information-col-item" style="color: {{ data['shipTypeInfo']['Cruiser']['PVP']['prInfo']['color'] }};">{{ data['shipTypeInfo']['Cruiser']['PVP']['prInfo']['value'] }}</div>
                    <div class="information-col-item" style="color: {{ data['shipTypeInfo']['Cruiser']['PVP']['shipInfo']['avgInfo']['damageData']['color'] }};">{{ data['shipTypeInfo']['Cruiser']['PVP']['shipInfo']['avgInfo']['damage'] }}</div>
                    <div class="information-col-item">{{ data['shipTypeInfo']['Cruiser']['PVP']['shipInfo']['avgInfo']['frags'] }}</div>
                    <div class="information-col-item">{{ data['shipTypeInfo']['Cruiser']['PVP']['shipInfo']['hitRatioInfo']['ratioMain'] }}%</div>
                </div>
            {% endif %}
            {% if data['shipTypeInfo']['Destroyer']['PVP']['battle'] %}
                <div class="information-col">
                    <div class="information-col-item">驱逐舰</div>
                    <div class="information-col-item">{{ data['shipTypeInfo']['Destroyer']['PVP']['shipInfo']['battleInfo']['battle'] }}</div>
                    <div class="information-col-item" style="color: {{ data['shipTypeInfo']['Destroyer']['PVP']['shipInfo']['avgInfo']['winsData']['color'] }};">{{ data['shipTypeInfo']['Destroyer']['PVP']['shipInfo']['avgInfo']['win'] }}%</div>
                    <div class="information-col-item" style="color: {{ data['shipTypeInfo']['Destroyer']['PVP']['prInfo']['color'] }};">{{ data['shipTypeInfo']['Destroyer']['PVP']['prInfo']['value'] }}</div>
                    <div class="information-col-item" style="color: {{ data['shipTypeInfo']['Destroyer']['PVP']['shipInfo']['avgInfo']['damageData']['color'] }};">{{ data['shipTypeInfo']['Destroyer']['PVP']['shipInfo']['avgInfo']['damage'] }}</div>
                    <div class="information-col-item">{{ data['shipTypeInfo']['Destroyer']['PVP']['shipInfo']['avgInfo']['frags'] }}</div>
                    <div class="information-col-item">{{ data['shipTypeInfo']['Destroyer']['PVP']['shipInfo']['hitRatioInfo']['ratioMain'] }}%</div>
                </div>
            {% endif %}
            {% if data['shipTypeInfo']['AirCarrier']['PVP']['battle'] %}
                <div class="information-col">
                    <div class="information-col-item">航母</div>
                    <div class="information-col-item">{{ data['shipTypeInfo']['AirCarrier']['PVP']['shipInfo']['battleInfo']['battle'] }}</div>
                    <div class="information-col-item" style="color: {{ data['shipTypeInfo']['AirCarrier']['PVP']['shipInfo']['avgInfo']['winsData']['color'] }};">{{ data['shipTypeInfo']['AirCarrier']['PVP']['shipInfo']['avgInfo']['win'] }}%</div>
                    <div class="information-col-item" style="color: {{ data['shipTypeInfo']['AirCarrier']['PVP']['prInfo']['color'] }};">{{ data['shipTypeInfo']['AirCarrier']['PVP']['prInfo']['value'] }}</div>
                    <div class="information-col-item" style="color: {{ data['shipTypeInfo']['AirCarrier']['PVP']['shipInfo']['avgInfo']['damageData']['color'] }};">{{ data['shipTypeInfo']['AirCarrier']['PVP']['shipInfo']['avgInfo']['damage'] }}</div>
                    <div class="information-col-item">{{ data['shipTypeInfo']['AirCarrier']['PVP']['shipInfo']['avgInfo']['frags'] }}</div>
                    <div class="information-col-item">{{ data['shipTypeInfo']['AirCarrier']['PVP']['shipInfo']['hitRatioInfo']['ratioMain'] }}%</div>
                </div>
            {% endif %}
            {% if data['shipTypeInfo']['Submarine']['PVP']['battle'] %}
                <div class="information-col">
                    <div class="information-col-item">潜艇</div>
                    <div class="information-col-item">{{ data['shipTypeInfo']['Submarine']['PVP']['shipInfo']['battleInfo']['battle'] }}</div>
                    <div class="information-col-item" style="color: {{ data['shipTypeInfo']['Submarine']['PVP']['shipInfo']['avgInfo']['winsData']['color'] }};">{{ data['shipTypeInfo']['Submarine']['PVP']['shipInfo']['avgInfo']['win'] }}%</div>
                    <div class="information-col-item" style="color: {{ data['shipTypeInfo']['Submarine']['PVP']['prInfo']['color'] }};">{{ data['shipTypeInfo']['Submarine']['PVP']['prInfo']['value'] }}</div>
                    <div class="information-col-item" style="color: {{ data['shipTypeInfo']['Submarine']['PVP']['shipInfo']['avgInfo']['damageData']['color'] }};">{{ data['shipTypeInfo']['Submarine']['PVP']['shipInfo']['avgInfo']['damage'] }}</div>
                    <div class="information-col-item">{{ data['shipTypeInfo']['Submarine']['PVP']['shipInfo']['avgInfo']['frags'] }}</div>
                    <div class="information-col-item">{{ data['shipTypeInfo']['Submarine']['PVP']['shipInfo']['hitRatioInfo']['ratioTpd'] }}%</div>
                </div>
            {% endif %}
        </div>

        <div class="random-header one-background-color">战斗类型</div>
        <div class="information-body one-background-color data-battle-type">
            <div class="information-col ">
                <div class="information-col-item">类型</div>
                <div class="information-col-item">场次</div>
                <div class="information-col-item">胜率</div>
                <div class="information-col-item">PR</div>
                <div class="information-col-item">场均</div>
                <div class="information-col-item">击杀</div>
                <div class="information-col-item">命中</div>
            </div>
            {% if data['battleTypeInfo']['PVP_SOLO']['battle'] %}
                <div class="information-col">
                    <div class="information-col-item">单野</div>
                    <div class="information-col-item">{{ data['battleTypeInfo']['PVP_SOLO']['shipInfo']['battleInfo']['battle'] }}</div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfo']['PVP_SOLO']['shipInfo']['avgInfo']['winsData']['color'] }};">{{ data['battleTypeInfo']['PVP_SOLO']['shipInfo']['avgInfo']['win'] }}%
                    </div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfo']['PVP_SOLO']['prInfo']['color'] }};">{{ data['battleTypeInfo']['PVP_SOLO']['prInfo']['value'] }}</div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfo']['PVP_SOLO']['shipInfo']['avgInfo']['damageData']['color'] }};">{{ data['battleTypeInfo']['PVP_SOLO']['shipInfo']['avgInfo']['damage'] }}</div>
                    <div class="information-col-item">{{ '%.2f' | format(data['battleTypeInfo']['PVP_SOLO']['shipInfo']['avgInfo']['frags']) }}</div>
                    <div class="information-col-item">{{ '%.2f' | format(data['battleTypeInfo']['PVP_SOLO']['shipInfo']['hitRatioInfo']['ratioMain']) }}%</div>
                </div>
            {% endif %}

            {% if data['battleTypeInfo']['PVP_DIV2']['battle'] %}
                <div class="information-col">
                    <div class="information-col-item">自行车</div>
                    <div class="information-col-item">{{ data['battleTypeInfo']['PVP_DIV2']['shipInfo']['battleInfo']['battle'] }}</div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfo']['PVP_DIV2']['shipInfo']['avgInfo']['winsData']['color'] }};">{{ data['battleTypeInfo']['PVP_DIV2']['shipInfo']['avgInfo']['win'] }}%
                    </div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfo']['PVP_DIV2']['prInfo']['color'] }};">{{ data['battleTypeInfo']['PVP_DIV2']['prInfo']['value'] }}</div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfo']['PVP_DIV2']['shipInfo']['avgInfo']['damageData']['color'] }};">{{ data['battleTypeInfo']['PVP_DIV2']['shipInfo']['avgInfo']['damage'] }}</div>
                    <div class="information-col-item">{{ '%.2f' | format(data['battleTypeInfo']['PVP_DIV2']['shipInfo']['avgInfo']['frags']) }}</div>
                    <div class="information-col-item">{{ '%.2f' | format(data['battleTypeInfo']['PVP_DIV2']['shipInfo']['hitRatioInfo']['ratioMain']) }}%</div>
                </div>
            {% endif %}

            {% if data['battleTypeInfo']['PVP_DIV3']['battle'] %}
                <div class="information-col">
                    <div class="information-col-item">三轮车</div>
                    <div class="information-col-item">{{ data['battleTypeInfo']['PVP_DIV3']['shipInfo']['battleInfo']['battle'] }}</div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfo']['PVP_DIV3']['shipInfo']['avgInfo']['winsData']['color'] }};">{{ data['battleTypeInfo']['PVP_DIV3']['shipInfo']['avgInfo']['win'] }}%
                    </div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfo']['PVP_DIV3']['prInfo']['color'] }};">{{ data['battleTypeInfo']['PVP_DIV3']['prInfo']['value'] }}</div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfo']['PVP_DIV3']['shipInfo']['avgInfo']['damageData']['color'] }};">{{ data['battleTypeInfo']['PVP_DIV3']['shipInfo']['avgInfo']['damage'] }}</div>
                    <div class="information-col-item">{{ '%.2f' | format(data['battleTypeInfo']['PVP_DIV3']['shipInfo']['avgInfo']['frags']) }}</div>
                    <div class="information-col-item">{{ '%.2f' | format(data['battleTypeInfo']['PVP_DIV3']['shipInfo']['hitRatioInfo']['ratioMain']) }}%</div>
                </div>
            {% endif %}

            {% if data['battleTypeInfo']['RANK_SOLO']['battle'] %}
                <div class="information-col">
                    <div class="information-col-item">排位</div>
                    <div class="information-col-item">{{ data['battleTypeInfo']['RANK_SOLO']['shipInfo']['battleInfo']['battle'] }}</div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfo']['RANK_SOLO']['shipInfo']['avgInfo']['winsData']['color'] }};">{{ data['battleTypeInfo']['RANK_SOLO']['shipInfo']['avgInfo']['win'] }}%
                    </div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfo']['RANK_SOLO']['prInfo']['color'] }};">{{ data['battleTypeInfo']['RANK_SOLO']['prInfo']['value'] }}</div>
                    <div class="information-col-item"
                         style="color: {{ data['battleTypeInfo']['RANK_SOLO']['shipInfo']['avgInfo']['damageData']['color'] }};">{{ data['battleTypeInfo']['RANK_SOLO']['shipInfo']['avgInfo']['damage'] }}</div>
                    <div class="information-col-item">{{ '%.2f' | format(data['battleTypeInfo']['RANK_SOLO']['shipInfo']['avgInfo']['frags']) }}</div>
                    <div class="information-col-item">{{ '%.2f' | format(data['battleTypeInfo']['RANK_SOLO']['shipInfo']['hitRatioInfo']['ratioMain']) }}%</div>
                </div>
            {% endif %}
        </div>
        <div class="random-header one-background-color">最高记录</div>
        <div class="frag-data">
            <div class="frag-data-col">
                <div class="frag-item one-background-color">
                    <div class="frag-key">伤害</div>
                    <div class="frag-value">{{ data['battleTypeInfo']['PVP']['shipInfo']['maxInfo']['maxDamageDealt']['value'] }}</div>
                </div>
                <div class="frag-item one-background-color">
                    <div class="frag-key">潜在</div>
                    <div class="frag-value">{{ data['battleTypeInfo']['PVP']['shipInfo']['maxInfo']['maxTotalAgro']['value'] }}</div>
                </div>
                <div class="frag-item one-background-color">
                    <div class="frag-key">侦查</div>
                    <div class="frag-value">{{ data['battleTypeInfo']['PVP']['shipInfo']['maxInfo']['maxScoutingDamage']['value'] }}</div>
                </div>
            </div>
            <div class="frag-data-col">
                <div class="frag-item one-background-color">
                    <div class="frag-key">击杀</div>
                    <div class="frag-value">{{ data['battleTypeInfo']['PVP']['shipInfo']['maxInfo']['maxFrags']['value'] }}</div>
                </div>
                <div class="frag-item one-background-color">
                    <div class="frag-key">飞机数</div>
                    <div class="frag-value">{{ data['battleTypeInfo']['PVP']['shipInfo']['maxInfo']['maxPlanesKilled']['value'] }}</div>
                </div>
                <div class="frag-item one-background-color">
                    <div class="frag-key">经验</div>
                    <div class="frag-value">{{ data['battleTypeInfo']['PVP']['shipInfo']['maxInfo']['maxXp']['value'] }}</div>
                </div>
            </div>
        </div>
        <div class="chart-box">
            <div class="chart-bar"></div>
            <div class="chart-pie"></div>
        </div>
        <div class="footer">
            <p>频道搜索"战舰世界-yuyuko"即可使用稳定的腾讯官方机器人~</p>
            <p>©github:wows-yuyuko</p>
        </div>
    </div>
</div>
</body>

{% if template_path and template_path/"echarts.js" %}
    <script src="file:\\{{template_path}}/echarts.js"></script>
{% else %}
    <script src="https://cdn.bootcdn.net/ajax/libs/echarts/5.3.3/echarts.min.js"></script>
{% endif %}
<script src="file:\\{{template_path}}/main.js" type="text/javascript"></script>
<script>
    window.onload = function () {
        drawBarChart();
        drawPieChart();
    };

    function drawBarChart() {
        var barChart = echarts.init(document.querySelector('.chart-bar'));
        var barOption = {
            animation: false,
            tooltip: {},
            label: {
                position: 'top',
                show: true,
                fontSize: '15',
                color: '#303133',
            },
            xAxis: {
                data: ['I', 'II', 'III', 'IV', 'V', 'VI', 'VII', 'VIII', 'IX', 'X', '★'],
                axisLabel: {
                    align: 'center',
                    fontSize: '20',
                }
            },
            yAxis: {
                axisLabel: {
                    align: 'center',
                    fontSize: '20',
                }
            },
            series: [{
                name: '场次',
                type: 'bar',
                data: [
                    {{ data['battleCountAll']['1'] }},
                    {{ data['battleCountAll']['2'] }},
                    {{ data['battleCountAll']['3'] }},
                    {{ data['battleCountAll']['4'] }},
                    {{ data['battleCountAll']['5'] }},
                    {{ data['battleCountAll']['6'] }},
                    {{ data['battleCountAll']['7'] }},
                    {{ data['battleCountAll']['8'] }},
                    {{ data['battleCountAll']['9'] }},
                    {{ data['battleCountAll']['10'] }},
                    {{ data['battleCountAll']['11'] }},
                ],
                itemStyle: {
                    color: '#D6ECFB40',
                    borderWidth: 1,
                    borderType: 'solid',
                    borderColor: '#9FB8FF',
                    shadowColor: '#9FB8FF',
                    shadowBlur: 3
                },
            }]
        };

        barChart.setOption(barOption);
    }

    function drawPieChart() {
        var pieChart = echarts.init(document.querySelector('.chart-pie'));
        var pieOption = {
            animation: false,
            tooltip: {},
            color: ["#FBE5D6", "#E2F0D9", "#F2E2E2", "#DAE3F3", "#D9FFFF"],
            series: [
                {
                    name: this.title,
                    type: 'pie',
                    selectedMode: 'single',
                    radius: ['30%', '80%'],
                    clockwise: false,
                    itemStyle: {
                        borderWidth: 5,
                        borderColor: '#F2F2F2'
                    },
                    label: {
                        position: 'inside',
                        formatter: '{b}\n{d}%',
                        fontSize: 20,
                        fontWeight: 'bold',
                    },
                    data: [
                        { value: {{ data['shipTypeInfo']['Battleship']['PVP']['shipInfo']['battleInfo']['battle'] }}, name: 'BB' },
                        { value: {{ data['shipTypeInfo']['Cruiser']['PVP']['shipInfo']['battleInfo']['battle'] }}, name: 'CA' },
                        { value: {{ data['shipTypeInfo']['Destroyer']['PVP']['shipInfo']['battleInfo']['battle'] }}, name: 'DD' },
                        { value: {{ data['shipTypeInfo']['AirCarrier']['PVP']['shipInfo']['battleInfo']['battle'] }}, name: 'CV' },
                        { value: {{ data['shipTypeInfo']['Submarine']['PVP']['shipInfo']['battleInfo']['battle'] }}, name: 'SS' }
                    ]
                }],
            graphic: {
                elements: [{
                    type: 'text',
                    left: 'center',
                    top: 'center',
                    style: {
                        text: '舰船\n场次',
                        fontSize: 35,
                        textAlign: 'center',
                        width: 30,
                        height: 30,
                        fill: 'darkgray'
                    }
                }]
            }
        };

        pieChart.setOption(pieOption);
    }
</script>
</html>
